==> grunt-banana-checker-0.11.1.tgz: package/src/cli.js <==
#!/usr/bin/env node
'use strict';

// argv: 0 = bin/node, 1 = src/cli.js, 2... = params
const params = process.argv.slice( 2 );
const dirs = [];
const options = {};
for ( const param of params ) {
	if ( !param.startsWith( '--' ) ) {
		dirs.push( param );
		continue;
	}
	// eslint-disable-next-line security/detect-unsafe-regex
	const [ , key, value ] = /([a-zA-Z]+)(?:=(.+))?/.exec( param.slice( 2 ) );
	switch ( key ) {
		// String options
		case 'sourceFile':
		case 'documentationFile':
			options[ key ] = value;
			break;

		// Boolean options
		case 'disallowBlankTranslations':
		case 'disallowUnusedDocumentation':
		case 'disallowEmptyDocumentation':
		case 'allowLeadingWhitespace':
		case 'ignoreMissingBlankTranslations':
		case 'requireCompleteMessageDocumentation':
		case 'requireLowerCase':
		case 'requireMetadata':
		case 'disallowDuplicateTranslations':
		case 'disallowUnusedTranslations':
		case 'requireCompletelyUsedParameters':
		case 'allowTrailingWhitespace':
			if ( value === '1' || value === 'true' ) {
				options[ key ] = true;
			} else if ( value === '0' || value === 'false' ) {
				options[ key ] = false;
			} else {
				console.error( `banana-check: Invalid option ignored, --${key}=${value}` );
			}
			break;

		// Array options
		case 'requireCompleteTranslationLanguages':
		case 'requireCompleteTranslationMessages':
		case 'requireKeyPrefix':
			options[ key ] = ( value || '' ).split( ',' );
			break;

		default:
			console.error( `banana-check: Invalid option ignored, --${key}` );
	}
}

if ( !dirs.length ) {
	console.error( 'banana-check: Specify one or more directories.' );
	// eslint-disable-next-line no-process-exit
	process.exit( 1 );
}

const bananaChecker = require( '../src/banana.js' );
const result = dirs.every( ( dir ) => {
	return bananaChecker(
		dir,
		options,
		console.error
	);
} );
if ( !result ) {
	// eslint-disable-next-line no-process-exit
	process.exit( 1 );
}

console.log( `Checked ${dirs.length} message director${( dirs.length > 1 ? 'ies' : 'y' )}.` );

==> grunt-banana-checker-0.12.0.tgz: package/src/cli.js <==
#!/usr/bin/env node
'use strict';

// argv: 0 = bin/node, 1 = src/cli.js, 2... = params
const params = process.argv.slice( 2 );
const dirs = [];
const options = {};
for ( const param of params ) {
	if ( !param.startsWith( '--' ) ) {
		dirs.push( param );
		continue;
	}
	// eslint-disable-next-line security/detect-unsafe-regex
	const [ , key, value ] = /([a-zA-Z]+)(?:=(.+))?/.exec( param.slice( 2 ) );
	switch ( key ) {
		// String options
		case 'sourceFile':
		case 'documentationFile':
			options[ key ] = value;
			break;

		// Boolean options
		case 'autofix':
		case 'disallowBlankTranslations':
		case 'disallowUnusedDocumentation':
		case 'disallowEmptyDocumentation':
		case 'allowLeadingWhitespace':
		case 'ignoreMissingBlankTranslations':
		case 'requireCompleteMessageDocumentation':
		case 'requireLowerCase':
		case 'requireMetadata':
		case 'disallowDuplicateTranslations':
		case 'disallowUnusedTranslations':
		case 'requireCompletelyUsedParameters':
		case 'allowTrailingWhitespace':
			if ( value === '1' || value === 'true' ) {
				options[ key ] = true;
			} else if ( value === '0' || value === 'false' ) {
				options[ key ] = false;
			} else {
				console.error( `banana-check: Invalid option ignored, --${ key }=${ value }` );
			}
			break;

		// Array options
		case 'requireCompleteTranslationLanguages':
		case 'requireCompleteTranslationMessages':
		case 'requireKeyPrefix':
			options[ key ] = ( value || '' ).split( ',' );
			break;

		default:
			console.error( `banana-check: Invalid option ignored, --${ key }` );
	}
}

if ( !dirs.length ) {
	console.error( 'banana-check: Specify one or more directories.' );
	// eslint-disable-next-line n/no-process-exit
	process.exit( 1 );
}

const bananaChecker = require( '../src/banana.js' );
let result = true;
dirs.forEach( ( dir ) => {
	result = bananaChecker(
		dir,
		options,
		console.error
	) && result;
} );
if ( !result ) {
	// eslint-disable-next-line n/no-process-exit
	process.exit( 1 );
}

console.log( `Checked ${ dirs.length } message director${ ( dirs.length > 1 ? 'ies' : 'y' ) }.` );
